#include "ee24c16.h"
#include "common.h"
extern volatile uint32_t ttms;
static volatile uint32_t cntr;

uint8_t ee24c16read_page (uint16_t addr, uint8_t* buff)
{
  cntr = ttms;
  uint8_t addr_tmp = EE16ADDR + (addr/255<<1);

  I2C1->CR2 = 1<<16 | I2C_CR2_START | addr_tmp;
  while((I2C1->ISR & I2C_ISR_TXIS)==0) { if(ttms - cntr > I2CWAIT) return 0; }

  I2C1->TXDR = (uint8_t) addr;
  while((I2C1->ISR & I2C_ISR_TC)==0) { if(ttms - cntr > I2CWAIT) return 0; }

  I2C1->CR2 = 16<<16 | I2C_CR2_START | addr_tmp | I2C_CR2_AUTOEND | I2C_CR2_RD_WRN;
  for(uint8_t i=0; i <= 16 - 1; i++) {
    while((I2C1->ISR & I2C_ISR_RXNE)==0) { if(ttms - cntr > I2CWAIT) return 0; }
    *(buff+i) = (uint8_t)I2C1->RXDR;
    buff[i]  = I2C1->RXDR ;
  }
  return 1;
}

uint8_t ee24c16write_page (uint16_t addr, uint8_t *buff)
{
  uint8_t addr_tmp = EE16ADDR + (addr/255<<1);
  
  cntr = ttms;
  I2C1->CR2 = I2C_CR2_AUTOEND | (17<<16) | (addr_tmp) | I2C_CR2_START;
  while (!(I2C1->ISR & I2C_ISR_TXE))  { if(ttms - cntr > I2CWAIT) return 0; }; // TXE регистр данных передачи пуст (буфер передачи пуст)

  I2C1->TXDR =(uint8_t) addr;  
  while (!(I2C1->ISR & I2C_ISR_TXIS)) { if(ttms - cntr > I2CWAIT) return 0; };
  
  cntr = ttms;
  for (uint8_t i = 0; i <= 16 - 1; i++) {
    while (!(I2C1->ISR & I2C_ISR_TXIS))  // TXIS // ждем пока TXDR станет пустым и готовым к новым данным
    if(ttms - cntr > I2CWAIT) return 0;  //
    I2C1->TXDR = buff[i] ; //
  }
  while((I2C1->ISR & I2C_ISR_STOPF)==0) {}; // не знаю нужна проверка?
  return 1;
}

uint8_t ee24c16rp(uint8_t page, uint8_t* buff)
{
  uint8_t addr = page * 16;
  return ee24c16read_page (addr, buff);
}

uint8_t ee24c16wp(uint8_t page, uint8_t *buff)
{
  uint8_t addr = page * 16;
  return ee24c16write_page(addr, buff);
}